import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import DropdownValueOption from './DropdownValueOption';


const TestDropdownValueOption = DropdownValueOption({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdownValueOption'
});

describe('DropdownValueOption', () => {

    it('should change value when clicked and not selected', () => {
        let value = null;

        const option = TestUtils.renderIntoDocument(
            <TestDropdownValueOption onChange={ () => value = 'test' } selected={ false } value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(value).toBe('test');
    });

    it('should not change value when clicked and is selected', () => {
        let value = null;

        const option = TestUtils.renderIntoDocument(
            <TestDropdownValueOption onChange={ () => value = 'test' } selected={ true } value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(value).toBeNull();
    });

    [
        { name: 'should not change value when clicked and is not selected and disabled', data: { selected: false } },
        { name: 'should not change value when clicked and is selected and disabled', data: { selected: true } }
    ].forEach((fixture) => {
        it(fixture.name, () => {
            let value = null;

            const option = TestUtils.renderIntoDocument(
                <TestDropdownValueOption disabled={ true } onChange={ () => value = 'test' } selected={ fixture.data.selected } value="test" />
            );

            const node = ReactDOM.findDOMNode(option);
            TestUtils.Simulate.click(node);

            expect(value).toBeNull();
        });
    });

});
